%Rotations, Pictures, Animations
%Andy Ruina  March 20, 2019

% House coordinates: x column and y column
house = [0 0        % House
         1 0
         1 1
         0 1
         0 0
         0 inf      % Pen up command
         -.5 .5     % Roof
         .5 1.5
         1.5 .5]';  % Transpose to make x & y to rows
 
     
 p.g  = 1;   p.L = 1; p.c = .1; %Parameters    
 
 tfinal    = 50;  npoints = 501;
    tarray = linspace(0,tfinal, npoints);  % times for output
 theta0    = pi - .01;  omega0 = 0;        %ICs
    z0     = [theta0; omega0];
     
 f               = @(t,z) pendrhs(t,z,p);
 small           = 1e-7;
 options         = odeset('RelTol',small,'Abstol',small);
 [tarray zarray] = ode45(f,tarray, z0, options);
 theta = zarray(:,1); omega = zarray(:,2); % Unpack arrays
     
 house = house -[.5 1.5]';  %Put peak of roof at origin
  
 % ANIMATION LOOP
 for i = 1:npoints % start animation loop
    thetanow = theta(i);
    R     = [ cos(thetanow)  -sin(thetanow)
              sin(thetanow)   cos(thetanow)];
    housenew = R * house;
       x = housenew(1,:);  y = housenew(2,:);
    plot(x,y,'LineWidth', 10);        hold on;  % House
    plot(0,0, 'k*','MarkerSize', 20); hold off  % Origin
    axis equal; % Do this to make same scale for x and y
    axis([ -2 2 -2 2]); % To keep view at constant size and position
    shg % To make graph not burried behind other windows
    pause(.025)  % NEEDED.  Pause between frames
    
 end % end of animation loop

%%%%%%%%%%%%%%%%%%%%%%%%%%%
function zdot = pendrhs(t,z,p)
theta = z(1);  omega = z(2);
  thetadot = omega;
  %PENDULUM, with damping
  omegadot = -(p.g/p.L)* sin(theta) -p.c*thetadot;
zdot = [thetadot; omegadot];
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%


 